pub struct ConfigManagementConfigSyncState {
pub deployment_state: Option<ConfigManagementConfigSyncDeploymentState>,
pub sync_state: Option<ConfigManagementSyncState>,
pub version: Option<ConfigManagementConfigSyncVersion>,
}Expand description
State information for ConfigSync
This type is not used in any activity, and only used as part of another schema.
Fields
deployment_state: Option<ConfigManagementConfigSyncDeploymentState>Information about the deployment of ConfigSync, including the version of the various Pods deployed
sync_state: Option<ConfigManagementSyncState>The state of ConfigSync’s process to sync configs to a cluster
version: Option<ConfigManagementConfigSyncVersion>The version of ConfigSync deployed