pub struct ConfigManagementErrorResource {
pub resource_gvk: Option<ConfigManagementGroupVersionKind>,
pub resource_name: Option<String>,
pub resource_namespace: Option<String>,
pub source_path: Option<String>,
}Expand description
Model for a config file in the git repo with an associated Sync error
This type is not used in any activity, and only used as part of another schema.
Fields
resource_gvk: Option<ConfigManagementGroupVersionKind>Group/version/kind of the resource that is causing an error
resource_name: Option<String>Metadata name of the resource that is causing an error
resource_namespace: Option<String>Namespace of the resource that is causing an error
source_path: Option<String>Path in the git repo of the erroneous config