pub struct ConfigManagementGitConfig {
pub gcp_service_account_email: Option<String>,
pub https_proxy: Option<String>,
pub policy_dir: Option<String>,
pub secret_type: Option<String>,
pub sync_branch: Option<String>,
pub sync_repo: Option<String>,
pub sync_rev: Option<String>,
pub sync_wait_secs: Option<i64>,
}Expand description
Git repo configuration for a single cluster.
This type is not used in any activity, and only used as part of another schema.
Fields
gcp_service_account_email: Option<String>The GCP Service Account Email used for auth when secret_type is gcpServiceAccount.
https_proxy: Option<String>URL for the HTTPS proxy to be used when communicating with the Git repo.
policy_dir: Option<String>The path within the Git repository that represents the top level of the repo to sync. Default: the root directory of the repository.
secret_type: Option<String>Type of secret configured for access to the Git repo. Must be one of ssh, cookiefile, gcenode, token, gcpserviceaccount or none. The validation of this is case-sensitive. Required.
sync_branch: Option<String>The branch of the repository to sync from. Default: master.
sync_repo: Option<String>The URL of the Git repository to use as the source of truth.
sync_rev: Option<String>Git revision (tag or hash) to check out. Default HEAD.
sync_wait_secs: Option<i64>Period in seconds between consecutive syncs. Default: 15.