pub struct ConfigManagementHierarchyControllerConfig {
pub enable_hierarchical_resource_quota: Option<bool>,
pub enable_pod_tree_labels: Option<bool>,
pub enabled: Option<bool>,
}Expand description
Configuration for Hierarchy Controller
This type is not used in any activity, and only used as part of another schema.
Fields
enable_hierarchical_resource_quota: Option<bool>Whether hierarchical resource quota is enabled in this cluster.
enable_pod_tree_labels: Option<bool>Whether pod tree labels are enabled in this cluster.
enabled: Option<bool>Whether Hierarchy Controller is enabled in this cluster.