pub struct ConfigManagementMembershipState {
pub cluster_name: Option<String>,
pub config_sync_state: Option<ConfigManagementConfigSyncState>,
pub hierarchy_controller_state: Option<ConfigManagementHierarchyControllerState>,
pub membership_spec: Option<ConfigManagementMembershipSpec>,
pub operator_state: Option<ConfigManagementOperatorState>,
pub policy_controller_state: Option<ConfigManagementPolicyControllerState>,
}Expand description
Anthos Config Management: State for a single cluster.
This type is not used in any activity, and only used as part of another schema.
Fields
cluster_name: Option<String>The user-defined name for the cluster used by ClusterSelectors to group clusters together. This should match Membership’s membership_name, unless the user installed ACM on the cluster manually prior to enabling the ACM hub feature. Unique within a Anthos Config Management installation.
config_sync_state: Option<ConfigManagementConfigSyncState>Current sync status
hierarchy_controller_state: Option<ConfigManagementHierarchyControllerState>Hierarchy Controller status
membership_spec: Option<ConfigManagementMembershipSpec>Membership configuration in the cluster. This represents the actual state in the cluster, while the MembershipSpec in the FeatureSpec represents the intended state
operator_state: Option<ConfigManagementOperatorState>Current install status of ACM’s Operator
policy_controller_state: Option<ConfigManagementPolicyControllerState>PolicyController status