pub struct ConfigManagementPolicyController {
pub audit_interval_seconds: Option<i64>,
pub enabled: Option<bool>,
pub exemptable_namespaces: Option<Vec<String>>,
pub log_denies_enabled: Option<bool>,
pub monitoring: Option<ConfigManagementPolicyControllerMonitoring>,
pub mutation_enabled: Option<bool>,
pub referential_rules_enabled: Option<bool>,
pub template_library_installed: Option<bool>,
}Expand description
Configuration for Policy Controller
This type is not used in any activity, and only used as part of another schema.
Fields
audit_interval_seconds: Option<i64>Sets the interval for Policy Controller Audit Scans (in seconds). When set to 0, this disables audit functionality altogether.
enabled: Option<bool>Enables the installation of Policy Controller. If false, the rest of PolicyController fields take no effect.
exemptable_namespaces: Option<Vec<String>>The set of namespaces that are excluded from Policy Controller checks. Namespaces do not need to currently exist on the cluster.
log_denies_enabled: Option<bool>Logs all denies and dry run failures.
monitoring: Option<ConfigManagementPolicyControllerMonitoring>Monitoring specifies the configuration of monitoring.
mutation_enabled: Option<bool>Enable or disable mutation in policy controller. If true, mutation CRDs, webhook and controller deployment will be deployed to the cluster.
referential_rules_enabled: Option<bool>Enables the ability to use Constraint Templates that reference to objects other than the object currently being evaluated.
template_library_installed: Option<bool>Installs the default template library along with Policy Controller.