pub struct ConfigManagementPolicyControllerMonitoring {
pub backends: Option<Vec<String>>,
}Expand description
PolicyControllerMonitoring specifies the backends Policy Controller should export metrics to. For example, to specify metrics should be exported to Cloud Monitoring and Prometheus, specify backends: [“cloudmonitoring”, “prometheus”]
This type is not used in any activity, and only used as part of another schema.
Fields
backends: Option<Vec<String>>Specifies the list of backends Policy Controller will export to. An empty list would effectively disable metrics export.