pub struct ConfigManagementPolicyControllerVersion {
pub version: Option<String>,
}Expand description
The build version of Gatekeeper Policy Controller is using.
This type is not used in any activity, and only used as part of another schema.
Fields
version: Option<String>The gatekeeper image tag that is composed of ACM version, git tag, build number.