pub struct ConfigManagementSyncState {
pub code: Option<String>,
pub errors: Option<Vec<ConfigManagementSyncError>>,
pub import_token: Option<String>,
pub last_sync: Option<String>,
pub last_sync_time: Option<DateTime<Utc>>,
pub source_token: Option<String>,
pub sync_token: Option<String>,
}Expand description
State indicating an ACM’s progress syncing configurations to a cluster
This type is not used in any activity, and only used as part of another schema.
Fields
code: Option<String>Sync status code
errors: Option<Vec<ConfigManagementSyncError>>A list of errors resulting from problematic configs. This list will be truncated after 100 errors, although it is unlikely for that many errors to simultaneously exist.
import_token: Option<String>Token indicating the state of the importer.
last_sync: Option<String>Deprecated: use last_sync_time instead. Timestamp of when ACM last successfully synced the repo The time format is specified in https://golang.org/pkg/time/#Time.String
last_sync_time: Option<DateTime<Utc>>Timestamp type of when ACM last successfully synced the repo
source_token: Option<String>Token indicating the state of the repo.
sync_token: Option<String>Token indicating the state of the syncer.