pub struct IdentityServiceAzureADConfig {
pub client_id: Option<String>,
pub client_secret: Option<String>,
pub encrypted_client_secret: Option<Vec<u8>>,
pub kubectl_redirect_uri: Option<String>,
pub tenant: Option<String>,
}Expand description
Configuration for the AzureAD Auth flow.
This type is not used in any activity, and only used as part of another schema.
Fields
client_id: Option<String>ID for the registered client application that makes authentication requests to the Azure AD identity provider.
client_secret: Option<String>Input only. Unencrypted AzureAD client secret will be passed to the GKE Hub CLH.
encrypted_client_secret: Option<Vec<u8>>Output only. Encrypted AzureAD client secret.
kubectl_redirect_uri: Option<String>The redirect URL that kubectl uses for authorization.
tenant: Option<String>Kind of Azure AD account to be authenticated. Supported values are or for accounts belonging to a specific tenant.