pub struct IdentityServiceGoogleConfig {
pub disable: Option<bool>,
}Expand description
Configuration for the Google Plugin Auth flow.
This type is not used in any activity, and only used as part of another schema.
Fields
disable: Option<bool>Disable automatic configuration of Google Plugin on supported platforms.