pub struct ResourceOptions {
pub connect_version: Option<String>,
pub k8s_version: Option<String>,
pub v1beta1_crd: Option<bool>,
}Expand description
ResourceOptions represent options for Kubernetes resource generation.
This type is not used in any activity, and only used as part of another schema.
Fields
connect_version: Option<String>Optional. The Connect agent version to use for connect_resources. Defaults to the latest GKE Connect version. The version must be a currently supported version, obsolete versions will be rejected.
k8s_version: Option<String>Optional. Major version of the Kubernetes cluster. This is only used to determine which version to use for the CustomResourceDefinition resources, apiextensions/v1beta1 orapiextensions/v1.
v1beta1_crd: Option<bool>Optional. Use apiextensions/v1beta1 instead of apiextensions/v1 for CustomResourceDefinition resources. This option should be set for clusters with Kubernetes apiserver versions <1.16.