pub struct ServiceMeshMembershipSpec {
pub control_plane: Option<String>,
pub management: Option<String>,
}Expand description
Service Mesh: Spec for a single Membership for the servicemesh feature
This type is not used in any activity, and only used as part of another schema.
Fields
control_plane: Option<String>Enables automatic control plane management.
management: Option<String>Enables automatic Service Mesh management.