pub struct ServiceMeshMembershipState {
pub control_plane_management: Option<ServiceMeshControlPlaneManagement>,
pub data_plane_management: Option<ServiceMeshDataPlaneManagement>,
}Expand description
Service Mesh: State for a single Membership, as analyzed by the Service Mesh Hub Controller.
This type is not used in any activity, and only used as part of another schema.
Fields
control_plane_management: Option<ServiceMeshControlPlaneManagement>Output only. Status of control plane management
data_plane_management: Option<ServiceMeshDataPlaneManagement>Output only. Status of data plane management.