pub struct TypeMeta {
pub api_version: Option<String>,
pub kind: Option<String>,
}Expand description
TypeMeta is the type information needed for content unmarshalling of Kubernetes resources in the manifest.
This type is not used in any activity, and only used as part of another schema.
Fields
api_version: Option<String>APIVersion of the resource (e.g. v1).
kind: Option<String>Kind of the resource (e.g. Deployment).