pub struct ConfigManagementConfigSync {
pub allow_vertical_scale: Option<bool>,
pub enabled: Option<bool>,
pub git: Option<ConfigManagementGitConfig>,
pub oci: Option<ConfigManagementOciConfig>,
pub prevent_drift: Option<bool>,
pub source_format: Option<String>,
}Expand description
Configuration for Config Sync
This type is not used in any activity, and only used as part of another schema.
Fields
allow_vertical_scale: Option<bool>Set to true to allow the vertical scaling. Defaults to false which disallows vertical scaling. This field is deprecated.
enabled: Option<bool>Enables the installation of ConfigSync. If set to true, ConfigSync resources will be created and the other ConfigSync fields will be applied if exist. If set to false, all other ConfigSync fields will be ignored, ConfigSync resources will be deleted. If omitted, ConfigSync resources will be managed depends on the presence of git field.
git: Option<ConfigManagementGitConfig>Git repo configuration for the cluster.
oci: Option<ConfigManagementOciConfig>OCI repo configuration for the cluster
prevent_drift: Option<bool>Set to true to enable the Config Sync admission webhook to prevent drifts. If set to false, disables the Config Sync admission webhook and does not prevent drifts.
source_format: Option<String>Specifies whether the Config Sync Repo is in “hierarchical” or “unstructured” mode.